Export Package VRC : bcB40Pc4ca20
Update compared VRC:   B40 c4ca20
Only Package       : Yes
Based on sessions  : No
Script sources     : No
Function  sources  : Yes
Library sources    : No
---------------------------------------
C = Charts
q = Questions
c = Messages
l = Labels
d = Domains
t = Table Definitions
s = Sessions
p = Scripts
o = Objects
f = Forms
F = Form Dumps
m = Menus
M = Menu Dumps
r = Reports
i = Impl. Functions
b = Functions
h = Help Text Codes
----------------------
tbcstc000                           B40Pc4ca20
tbcsti000                           B40Pc4ca20
tbcswh010                           B40Pc4ca20
sbcsti0100m000                      B40Pc4ca20
pbcdllfbcttf001                     B40Pc4ca20 (without source)
pbcdllfbcttf002                     B40Pc4ca20 (without source)
pbcdllfbcttf006                     B40Pc4ca20 (without source)
pbcdllfcisli120                     B40Pc4ca20 (without source)
pbcdllfqmptc011                     B40Pc4ca20 (without source)
pbcdllfqmptc130                     B40Pc4ca20 (without source)
pbcdllfqmptc131                     B40Pc4ca20 (without source)
pbcdllftccom000                     B40Pc4ca20 (without source)
pbcdllftccom136                     B40Pc4ca20 (without source)
pbcdllftccom139                     B40Pc4ca20 (without source)
pbcdllftccom710                     B40Pc4ca20 (without source)
pbcdllftccom997                     B40Pc4ca20 (without source)
pbcdllftcibd999                     B40Pc4ca20 (without source)
pbcdllftcmcs010                     B40Pc4ca20 (without source)
pbcdllftcmcs040                     B40Pc4ca20 (without source)
pbcdllftctax000                     B40Pc4ca20 (without source)
pbcdllftdipu001                     B40Pc4ca20 (without source)
pbcdllftdipu002                     B40Pc4ca20 (without source)
pbcdllftdipu010                     B40Pc4ca20 (without source)
pbcdllftdipu100                     B40Pc4ca20 (without source)
pbcdllftdisa001                     B40Pc4ca20 (without source)
pbcdllftdpur000                     B40Pc4ca20 (without source)
pbcdllftdpur301                     B40Pc4ca20 (without source)
pbcdllftdpur306                     B40Pc4ca20 (without source)
pbcdllftdpur351                     B40Pc4ca20 (without source)
pbcdllftdpur450                     B40Pc4ca20 (without source)
pbcdllftdpur451                     B40Pc4ca20 (without source)
pbcdllftdsls000                     B40Pc4ca20 (without source)
pbcdllftdsls407                     B40Pc4ca20 (without source)
pbcdllftfacp000                     B40Pc4ca20 (without source)
pbcdllftfcmg000                     B40Pc4ca20 (without source)
pbcdllftfcmg001                     B40Pc4ca20 (without source)
pbcdllftfcmg003                     B40Pc4ca20 (without source)
pbcdllftfcmg101                     B40Pc4ca20 (without source)
pbcdllftfcmg110                     B40Pc4ca20 (without source)
pbcdllftfcmg112                     B40Pc4ca20 (without source)
pbcdllftfcmg204                     B40Pc4ca20 (without source)
pbcdllftfcmg301                     B40Pc4ca20 (without source)
pbcdllftfcmg500                     B40Pc4ca20 (without source)
pbcdllftfcmg502                     B40Pc4ca20 (without source)
pbcdllftfcmg505                     B40Pc4ca20 (without source)
pbcdllftfgld004                     B40Pc4ca20 (without source)
pbcdllfticst001                     B40Pc4ca20 (without source)
pbcdllftipcf000                     B40Pc4ca20 (without source)
pbcdllftipcs025                     B40Pc4ca20 (without source)
pbcdllftirou001                     B40Pc4ca20 (without source)
pbcdllftisfc000                     B40Pc4ca20 (without source)
pbcdllftisfc001                     B40Pc4ca20 (without source)
pbcdllftisfc010                     B40Pc4ca20 (without source)
pbcdllftitrp000                     B40Pc4ca20 (without source)
pbcdllftpctm000                     B40Pc4ca20 (without source)
pbcdllftpctm020                     B40Pc4ca20 (without source)
pbcdllftpctm100                     B40Pc4ca20 (without source)
pbcdllftpctm110                     B40Pc4ca20 (without source)
pbcdllftppdm043                     B40Pc4ca20 (without source)
pbcdllftppdm600                     B40Pc4ca20 (without source)
pbcdllftppin010                     B40Pc4ca20 (without source)
pbcdllftppin011                     B40Pc4ca20 (without source)
pbcdllftppin020                     B40Pc4ca20 (without source)
pbcdllftpppc005                     B40Pc4ca20 (without source)
pbcdllftpppc200                     B40Pc4ca20 (without source)
pbcdllftpppc211                     B40Pc4ca20 (without source)
pbcdllftpppc215                     B40Pc4ca20 (without source)
pbcdllftpppc305                     B40Pc4ca20 (without source)
pbcdllftpppc350                     B40Pc4ca20 (without source)
pbcdllftppss200                     B40Pc4ca20 (without source)
pbcdllftppss615                     B40Pc4ca20 (without source)
pbcdllftpptc220                     B40Pc4ca20 (without source)
pbcdllftpptc230                     B40Pc4ca20 (without source)
pbcdllftpptc240                     B40Pc4ca20 (without source)
pbcdllftpptc250                     B40Pc4ca20 (without source)
pbcdllftpptc260                     B40Pc4ca20 (without source)
pbcdllftsacm220                     B40Pc4ca20 (without source)
pbcdllftscfg200                     B40Pc4ca20 (without source)
pbcdllftsctm110                     B40Pc4ca20 (without source)
pbcdllftsmdm030                     B40Pc4ca20 (without source)
pbcdllftsmdm200                     B40Pc4ca20 (without source)
pbcdllftsmdm400                     B40Pc4ca20 (without source)
pbcdllftssoc205                     B40Pc4ca20 (without source)
pbcdllftsspc210                     B40Pc4ca20 (without source)
pbcdllfwhina310                     B40Pc4ca20 (without source)
pbcdllfwhinh000                     B40Pc4ca20 (without source)
pbcdllfwhinp100                     B40Pc4ca20 (without source)
pbcdllfwhwmd230                     B40Pc4ca20 (without source)
pbcdllfwhwmd302                     B40Pc4ca20 (without source)
pbcdllmcisli000                     B40Pc4ca20 (without source)
pbcdllmcisli220                     B40Pc4ca20 (without source)
pbcdllmcisli305                     B40Pc4ca20 (without source)
pbcdllmcprpd100                     B40Pc4ca20 (without source)
pbcdllmcprrp100                     B40Pc4ca20 (without source)
pbcdllmtccom130                     B40Pc4ca20 (without source)
pbcdllmtcibd001                     B40Pc4ca20 (without source)
pbcdllmtcibd402                     B40Pc4ca20 (without source)
pbcdllmtcmcs003                     B40Pc4ca20 (without source)
pbcdllmtcmcs036                     B40Pc4ca20 (without source)
pbcdllmtdpcg030                     B40Pc4ca20 (without source)
pbcdllmtdpur100                     B40Pc4ca20 (without source)
pbcdllmtdpur101                     B40Pc4ca20 (without source)
pbcdllmtdpur150                     B40Pc4ca20 (without source)
pbcdllmtdpur151                     B40Pc4ca20 (without source)
pbcdllmtdpur401                     B40Pc4ca20 (without source)
pbcdllmtdsls401                     B40Pc4ca20 (without source)
pbcdllmtdsta000                     B40Pc4ca20 (without source)
pbcdllmtfacp240                     B40Pc4ca20 (without source)
pbcdllmtfacp250                     B40Pc4ca20 (without source)
pbcdllmticst002                     B40Pc4ca20 (without source)
pbcdllmtsctm300                     B40Pc4ca20 (without source)
pbcdllmtssoc000                     B40Pc4ca20 (without source)
pbcdllmtssoc200                     B40Pc4ca20 (without source)
pbcdllmtssoc220                     B40Pc4ca20 (without source)
pbcdllmtssoc850                     B40Pc4ca20 (without source)
pbcdllmtssoc860                     B40Pc4ca20 (without source)
pbcdllmtsspc130                     B40Pc4ca20 (without source)
pbcdllmwhinh200                     B40Pc4ca20 (without source)
pbcdllmwhinr110                     B40Pc4ca20 (without source)
pbcdllmwhltc100                     B40Pc4ca20 (without source)
pbcdllmwhwmd215                     B40Pc4ca20 (without source)
pbcintdll0002                       B40Pc4ca20 (without source)
pbcintdll0007                       B40Pc4ca20 (without source)
pbcmttdll0004                       B40Pc4ca20 (without source)
pbcstc000                           B40Pc4ca20 (without source)
pbcstc0100                          B40Pc4ca20 (without source)
pbcstc024                           B40Pc4ca20 (without source)
pbcstf014                           B40Pc4ca20 (without source)
pbcsti000                           B40Pc4ca20 (without source)
pbcsti003                           B40Pc4ca20 (without source)
pbcsti0100                          B40Pc4ca20 (without source)
pbcswh008                           B40Pc4ca20 (without source)
fbcsti0100m00032                    B40Pc4ca20
bbcswh0001                          B40Pc4ca20 (with source)
bbcswh0004                          B40Pc4ca20 (with source)
bbcswh0007                          B40Pc4ca20 (with source)
bbcswh0010                          B40Pc4ca20 (with source)
obcdllfbcttf001                     B40Pc4ca20
obcdllfbcttf002                     B40Pc4ca20
obcdllfbcttf006                     B40Pc4ca20
obcdllfcisli120                     B40Pc4ca20
obcdllfqmptc011                     B40Pc4ca20
obcdllfqmptc130                     B40Pc4ca20
obcdllfqmptc131                     B40Pc4ca20
obcdllftccom000                     B40Pc4ca20
obcdllftccom136                     B40Pc4ca20
obcdllftccom139                     B40Pc4ca20
obcdllftccom710                     B40Pc4ca20
obcdllftccom997                     B40Pc4ca20
obcdllftcibd999                     B40Pc4ca20
obcdllftcmcs010                     B40Pc4ca20
obcdllftcmcs040                     B40Pc4ca20
obcdllftctax000                     B40Pc4ca20
obcdllftdipu001                     B40Pc4ca20
obcdllftdipu002                     B40Pc4ca20
obcdllftdipu010                     B40Pc4ca20
obcdllftdipu100                     B40Pc4ca20
obcdllftdisa001                     B40Pc4ca20
obcdllftdpur000                     B40Pc4ca20
obcdllftdpur301                     B40Pc4ca20
obcdllftdpur306                     B40Pc4ca20
obcdllftdpur351                     B40Pc4ca20
obcdllftdpur450                     B40Pc4ca20
obcdllftdpur451                     B40Pc4ca20
obcdllftdsls000                     B40Pc4ca20
obcdllftdsls407                     B40Pc4ca20
obcdllftfacp000                     B40Pc4ca20
obcdllftfcmg000                     B40Pc4ca20
obcdllftfcmg001                     B40Pc4ca20
obcdllftfcmg003                     B40Pc4ca20
obcdllftfcmg101                     B40Pc4ca20
obcdllftfcmg110                     B40Pc4ca20
obcdllftfcmg112                     B40Pc4ca20
obcdllftfcmg204                     B40Pc4ca20
obcdllftfcmg301                     B40Pc4ca20
obcdllftfcmg500                     B40Pc4ca20
obcdllftfcmg502                     B40Pc4ca20
obcdllftfcmg505                     B40Pc4ca20
obcdllftfgld004                     B40Pc4ca20
obcdllfticst001                     B40Pc4ca20
obcdllftipcf000                     B40Pc4ca20
obcdllftipcs025                     B40Pc4ca20
obcdllftirou001                     B40Pc4ca20
obcdllftisfc000                     B40Pc4ca20
obcdllftisfc001                     B40Pc4ca20
obcdllftisfc010                     B40Pc4ca20
obcdllftitrp000                     B40Pc4ca20
obcdllftpctm000                     B40Pc4ca20
obcdllftpctm020                     B40Pc4ca20
obcdllftpctm100                     B40Pc4ca20
obcdllftpctm110                     B40Pc4ca20
obcdllftppdm043                     B40Pc4ca20
obcdllftppdm600                     B40Pc4ca20
obcdllftppin010                     B40Pc4ca20
obcdllftppin011                     B40Pc4ca20
obcdllftppin020                     B40Pc4ca20
obcdllftpppc005                     B40Pc4ca20
obcdllftpppc200                     B40Pc4ca20
obcdllftpppc211                     B40Pc4ca20
obcdllftpppc215                     B40Pc4ca20
obcdllftpppc305                     B40Pc4ca20
obcdllftpppc350                     B40Pc4ca20
obcdllftppss200                     B40Pc4ca20
obcdllftppss615                     B40Pc4ca20
obcdllftpptc220                     B40Pc4ca20
obcdllftpptc230                     B40Pc4ca20
obcdllftpptc240                     B40Pc4ca20
obcdllftpptc250                     B40Pc4ca20
obcdllftpptc260                     B40Pc4ca20
obcdllftsacm220                     B40Pc4ca20
obcdllftscfg200                     B40Pc4ca20
obcdllftsctm110                     B40Pc4ca20
obcdllftsmdm030                     B40Pc4ca20
obcdllftsmdm200                     B40Pc4ca20
obcdllftsmdm400                     B40Pc4ca20
obcdllftssoc205                     B40Pc4ca20
obcdllftsspc210                     B40Pc4ca20
obcdllfwhina310                     B40Pc4ca20
obcdllfwhinh000                     B40Pc4ca20
obcdllfwhinp100                     B40Pc4ca20
obcdllfwhwmd230                     B40Pc4ca20
obcdllfwhwmd302                     B40Pc4ca20
obcdllmcisli000                     B40Pc4ca20
obcdllmcisli220                     B40Pc4ca20
obcdllmcisli305                     B40Pc4ca20
obcdllmcprpd100                     B40Pc4ca20
obcdllmcprrp100                     B40Pc4ca20
obcdllmtccom130                     B40Pc4ca20
obcdllmtcibd001                     B40Pc4ca20
obcdllmtcibd402                     B40Pc4ca20
obcdllmtcmcs003                     B40Pc4ca20
obcdllmtcmcs036                     B40Pc4ca20
obcdllmtdpcg030                     B40Pc4ca20
obcdllmtdpur100                     B40Pc4ca20
obcdllmtdpur101                     B40Pc4ca20
obcdllmtdpur150                     B40Pc4ca20
obcdllmtdpur151                     B40Pc4ca20
obcdllmtdpur401                     B40Pc4ca20
obcdllmtdsls401                     B40Pc4ca20
obcdllmtdsta000                     B40Pc4ca20
obcdllmtfacp240                     B40Pc4ca20
obcdllmtfacp250                     B40Pc4ca20
obcdllmticst002                     B40Pc4ca20
obcdllmtsctm300                     B40Pc4ca20
obcdllmtssoc000                     B40Pc4ca20
obcdllmtssoc200                     B40Pc4ca20
obcdllmtssoc220                     B40Pc4ca20
obcdllmtssoc850                     B40Pc4ca20
obcdllmtssoc860                     B40Pc4ca20
obcdllmtsspc130                     B40Pc4ca20
obcdllmwhinh200                     B40Pc4ca20
obcdllmwhinr110                     B40Pc4ca20
obcdllmwhltc100                     B40Pc4ca20
obcdllmwhwmd215                     B40Pc4ca20
obcintdll0002                       B40Pc4ca20
obcintdll0007                       B40Pc4ca20
obcmttdll0004                       B40Pc4ca20
obcstc000                           B40Pc4ca20
obcstc0100                          B40Pc4ca20
obcstc024                           B40Pc4ca20
obcstf014                           B40Pc4ca20
obcsti000                           B40Pc4ca20
obcsti003                           B40Pc4ca20
obcsti0100                          B40Pc4ca20
obcswh008                           B40Pc4ca20
lbcbcsti000.pddd                    B40Pc4ca20
lbcbcsti000.pddp                    B40Pc4ca20
Fbcsti0100m00032                    B40Pc4ca20
hbcFCstc000.cccd                    B40Pc4ca20
hbcFCstc000.endt                    B40Pc4ca20
hbcFCstc000.stdt                    B40Pc4ca20
hbcFCsti000.pddd                    B40Pc4ca20
hbcFCsti000.pddp                    B40Pc4ca20
